@@ -310,6 +310,16 @@ class BaseVals(BaseModel):
     AllowSubBgmPlaying: int | None = None
     NotAccompanyWhenLinkedTargetMoveState: int | None = None
     NotTargetSkillIdArray: list[int] | None = None
+    ShortTurn: int | None = None
+    FieldIndividuality: int | None = None
+    BGId: int | None = None
+    BGType: int | None = None
+    BgmId: int | None = None
+    TakeOverFieldState: int | None = None
+    TakeOverNextWaveBGAndBGM: int | None = None
+    RemoveFieldBuffActorDeath: int | None = None
+    FieldBuffGrantType: int | None = None
+    Priority: int | None = None
     # Extra dataval from SkillLvEntty.DIC_KEY_APPLY_SUPPORT_SVT
     ApplySupportSvt: Optional[int] = None
     # These are not DataVals but guesses from SkillLvEntity and EventDropUpValInfo
@@ -1906,6 +1916,7 @@ class NiceStage(BaseModelORJson):
     bgm: NiceBgm
     fieldAis: list[FieldAi] = []
     call: list[int] = Field([], title="Summon these NPC IDs")
+    enemyFieldPosCount: int | None = None
     enemies: list[QuestEnemy] = []
 
 
@@ -1946,6 +1957,7 @@ class SupportServantEquip(BaseModelORJson):
 
 class SupportServantScript(BaseModelORJson):
     dispLimitCount: Optional[int] = None
+    eventDeckIndex: int | None = None
 
 
 class SupportServant(BaseModelORJson):
